@@ -1,7 +1,7 @@
 import collections
 
 from .utils import DslBase
-from .response.aggs import BucketData, AggData, TopHitsData
+from .response.aggs import BucketData, AggResponse, TopHitsData
 
 def A(name_or_agg, filter=None, **params):
     if filter is not None:
@@ -40,6 +40,10 @@ class Agg(DslBase):
     _type_name = 'agg'
     _type_shortcut = staticmethod(A)
     name = None
+
+    def __contains__(self, key):
+        return False
+
     def to_dict(self):
         d = super(Agg, self).to_dict()
         if 'meta' in d[self.name]:
@@ -47,13 +51,16 @@ class Agg(DslBase):
         return d
 
     def result(self, search, data):
-        return AggData(self, search, data)
+        return AggResponse(self, search, data)
 
 
 class AggBase(object):
     _param_defs = {
         'aggs': {'type': 'agg', 'hash': True},
     }
+    def __contains__(self, key):
+        return key in self._params.get('aggs', {})
+
     def __getitem__(self, agg_name):
         agg = self._params.setdefault('aggs', {})[agg_name] # propagate KeyError
 
